import React from 'react';
import { Card, Descriptions, Badge } from 'antd';
import dayjs from 'dayjs';
import useBool from '@/utils/hooks/useBool';
import { getTaIssueById } from '@/service/taissue';
import { getSysOrgById } from '@/service/sysorg';
import { processStatus } from '@/utils/biz';
import AttachList from './AttachList';

const today = (new Date()).toJSON().substring(0, 10);
const fmDate = dt => !dt ? '-' : dayjs(dt).format('YYYY-MM-DD');
const getStatusLabel = val => (processStatus.filter(x => x.value == val)[0])?.label;

export default (props) => {

  const { issueId, onIssueChange } = props;

  const [loading, startLoading, stopLoading] = useBool();
  const [detail, setDetail] = React.useState();

  const [
    isExpire,
    status,
  ] = React.useMemo(() => {
    if (!detail) return [];
    return [
      detail.processNode != '03' && today >= detail.expireDate,
      processStatus.filter(x => x.value == detail.processNode)[0],
    ]
  }, [detail]);

  React.useEffect(() => {
    if (issueId) {
      startLoading();
      getTaIssueById(issueId).then((res) => {
        if (onIssueChange) {
          onIssueChange(res);
        }

        if (res.orgId) {
          getSysOrgById(res.orgId).then(r => {
            stopLoading();
            setDetail({
              ...res,
              orgName: r.name
            });
          }).catch(() => {
            stopLoading();
            setDetail(res);
          });
        } else {
          stopLoading();
          setDetail(res);
        }
      }).catch(er => {
        stopLoading();
      });
    }
  }, [issueId]);

  return (
    <Card title="基础信息" loading={loading}>
      <Descriptions layout="vertical" column={3} bordered>
        <Descriptions.Item label="点位">{detail?.locName}</Descriptions.Item>
        <Descriptions.Item label="地址">{detail?.addr}</Descriptions.Item>
        <Descriptions.Item label="上报时间">{fmDate(detail?.createDate)}</Descriptions.Item>
        <Descriptions.Item label="上报人">{detail?.userName}</Descriptions.Item>
        <Descriptions.Item label="问题类型">{detail?.typeName}</Descriptions.Item>
        <Descriptions.Item label="流程状态">
          {
            isExpire ? <Badge status="error" text="已逾期" /> : <Badge status={status?.badge} text={status?.label} />
          }
        </Descriptions.Item>
        <Descriptions.Item label="截止日期">{fmDate(detail?.expireDate)}</Descriptions.Item>
        <Descriptions.Item label="责任单位" span={2}>{detail?.orgName}</Descriptions.Item>
        <Descriptions.Item label="办结时间">{fmDate(detail?.endDate)}</Descriptions.Item>
        <Descriptions.Item label="交办次数" span={2}>{detail?.processNum}</Descriptions.Item>
        <Descriptions.Item label="问题描述" span={3}>
          <div dangerouslySetInnerHTML={{ __html: detail?.content }}></div>
        </Descriptions.Item>
        <Descriptions.Item label="图片列表" span={3}>
          <AttachList attachList={detail?.attachList} />
        </Descriptions.Item>
      </Descriptions>
    </Card>
  )
}
