
/**
 * 数组 转 Tree
 * @param {*} arr 
 * @param {*} parent 
 * @param {*} key 
 * @returns 
 */
export function arr2Tree(arr = [], parent = 'parentId', key = 'key', rootId = '-1') {
  // 转换为字典
  const dict = arr.reduce((acc, item) => {
    return {
      ...acc,
      [item[key]]: {
        ...item,
        children: []
      }
    }
  }, {});

  // 挂载父子节点
  const tree = [];
  for (let item of arr) {
    const parentNodeId = item[parent];

    if (parentNodeId === rootId) {
      tree.push(dict[item[key]]);
    } else {
      const parentNode = dict[parentNodeId];
      if (parentNode) {
        parentNode.children.push(item);
      }
    }
  }

  return [tree, dict];
}

/**
 * 深度展平数组
 * @param {*} arr 
 * @returns 
 */
export function flatten(arr = []) {
  return arr.reduce((acc, it) => {
    const list = Array.isArray(it) ? flatten(it) : it
    return acc.concat(list);
  }, []);
}

/**
 * 深度数组去重
 * @param {*} arr 
 */
export function uniq(arr = []) {
  const list = flatten(arr);
  return list.reduce((acc, it) => {
    return acc.indexOf(it) > -1 ? acc : acc.concat(it)
  }, []);
}
